from PyObjCTools.TestSupport import TestCase, min_os_level
import Vision


class TestVNDetectBarcodesRequest(TestCase):
    def test_constants(self):
        self.assertEqual(Vision.VNDetectBarcodesRequestRevision1, 1)
        self.assertEqual(Vision.VNDetectBarcodesRequestRevision2, 2)

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertArgIsOut(
            Vision.VNDetectBarcodesRequest.supportedSymbologiesAndReturnError_, 0
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Vision


class TestVNGeneratePersonSegmentationRequest(TestCase):
    def test_constants(self):
        self.assertEqual(
            Vision.VNGeneratePersonSegmentationRequestQualityLevelAccurate, 0
        )
        self.assertEqual(
            Vision.VNGeneratePersonSegmentationRequestQualityLevelBalanced, 1
        )
        self.assertEqual(Vision.VNGeneratePersonSegmentationRequestQualityLevelFast, 2)

        self.assertEqual(Vision.VNGeneratePersonSegmentationRequestRevision1, 1)

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertArgIsBlock(
            Vision.VNGeneratePersonSegmentationRequest.initWithCompletionHandler_,
            0,
            b"v@@",
        )
        self.assertArgIsBlock(
            Vision.VNGeneratePersonSegmentationRequest.initWithFrameAnalysisSpacing_completionHandler_,
            1,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Vision


class TestVNStatefulRequest(TestCase):
    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertArgIsBlock(
            Vision.VNStatefulRequest.initWithCompletionHandler_, 0, b"v@@"
        )
        self.assertArgIsBlock(
            Vision.VNStatefulRequest.initWithFrameAnalysisSpacing_completionHandler_,
            1,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Vision


class TestVNDetectHumanRectanglesRequest(TestCase):
    def test_constants(self):
        self.assertEqual(Vision.VNDetectHumanRectanglesRequestRevision1, 1)
        self.assertEqual(Vision.VNDetectHumanRectanglesRequestRevision2, 2)

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertResultIsBOOL(Vision.VNDetectHumanRectanglesRequest.upperBodyOnly)
        self.assertArgIsBOOL(Vision.VNDetectHumanRectanglesRequest.setUpperBodyOnly_, 0)
